@@ -1,6 +1,6 @@
 package Ubic::Admin::Setup;
-{
-  $Ubic::Admin::Setup::VERSION = '1.57_01';
+BEGIN {
+  $Ubic::Admin::Setup::VERSION = '1.27';
 }
 
 # ABSTRACT: this module handles ubic setup: asks user some questions and configures your system
@@ -11,40 +11,13 @@ use warnings;
 
 use Getopt::Long 2.33;
 use Carp;
-use IPC::Open3;
-use File::Path;
-use File::Which;
-use File::Spec;
 
-use Ubic::AtomicFile;
 use Ubic::Settings;
 use Ubic::Settings::ConfigFile;
 
 my $batch_mode;
 my $quiet;
 
-sub _defaults {
-    if ($^O eq 'freebsd') {
-        return (
-            config => '/usr/local/etc/ubic/ubic.cfg',
-            data_dir => '/var/db/ubic',
-            service_dir => '/usr/local/etc/ubic/service',
-            log_dir => '/var/log/ubic',
-            example => '/usr/local/etc, /var',
-        );
-    }
-    else {
-        # fhs
-        return (
-            config => '/etc/ubic/ubic.cfg',
-            data_dir => '/var/lib/ubic',
-            service_dir => '/etc/ubic/service',
-            log_dir => '/var/log/ubic',
-            example => '/etc, /var',
-        );
-    }
-};
-
 sub print_tty {
     print @_ unless $quiet or $batch_mode;
 }
@@ -114,14 +87,6 @@ sub xsystem {
     die join ", ", @msg;
 }
 
-sub slurp {
-    my ($file) = @_;
-    open my $fh, '<', $file or die "Can't open $file: $!";
-    my $result = join '', <$fh>;
-    close $fh;
-    return $result;
-}
-
 sub setup {
 
     my $opt_reconfigure;
@@ -132,12 +97,8 @@ sub setup {
     my $opt_sticky_777 = 1;
     my $opt_install_services = 1;
     my $opt_crontab = 1;
-    my $opt_local;
 
-    # These options are documented in ubic-admin script POD.
-    # Don't forget to update their description if you change them.
     GetOptions(
-        'local!' => \$opt_local,
         'batch-mode' => \$batch_mode,
         'quiet' => \$quiet,
         'reconfigure!' => \$opt_reconfigure,
@@ -152,8 +113,6 @@ sub setup {
 
     die "Unexpected arguments '@ARGV'" if @ARGV;
 
-    my %defaults = _defaults();
-
     eval { Ubic::Settings->check_settings };
     unless ($@) {
         my $go = prompt_bool("Looks like ubic is already configured, do you want to reconfigure?", $opt_reconfigure);
@@ -161,66 +120,44 @@ sub setup {
         print_tty "\n";
     }
 
-    print_tty "Ubic can be installed either in your home dir or into standard system paths ($defaults{example}).\n";
+    print_tty "Ubic can be installed either in your home dir or into standard system paths (/etc, /var).\n";
     print_tty "You need to be root to install it into system.\n";
 
-    unless ($batch_mode) {
-        $batch_mode = prompt_bool("Would you like to configure as much as possible automatically?", 1);
-    }
-
-    # ideally, we want is_root option and local option to be orthogonal
-    # it's not completely true by now, though
     my $is_root = ( $> ? 0 : 1 );
-    my $local = $opt_local;
-    unless (defined $local) {
-        if ($is_root) {
-            my $ok = prompt_bool("You are root, install into system?", 1);
-            $local = 1 unless $ok; # root can install locally
-        }
-        else {
-            my $ok = prompt_bool("You are not root, install locally?", 1);
-            return unless $ok; # non-root user can't install into system
-            $local = 1;
-        }
+    if ($is_root) {
+        my $ok = prompt_bool("You are root, install into system?", 1);
+        return unless $ok;
+    }
+    else {
+        my $ok = prompt_bool("You are not root, install locally?", 1);
+        return unless $ok;
     }
 
-    my $local_dir;
-    if ($local) {
-        $local_dir = $ENV{HOME};
-        unless (defined $local_dir) {
+    my $home;
+    unless ($is_root) {
+        $home = $ENV{HOME};
+        unless (defined $home) {
             die "Can't find your home!";
         }
-        unless (-d $local_dir) {
-            die "Can't find your home dir '$local_dir'!";
+        unless (-d $home) {
+            die "Can't find your home dir '$home'!";
         }
     }
 
     print_tty "\nService dir is a directory with descriptions of your services.\n";
-    my $default_service_dir = (
-        defined($local_dir)
-        ? "$local_dir/ubic/service"
-        : $defaults{service_dir}
-    );
+    my $default_service_dir = ($is_root ? '/etc/ubic/service' : "$home/ubic/service");
     $default_service_dir = $opt_service_dir if defined $opt_service_dir;
     my $service_dir = prompt_str("Service dir?", $default_service_dir);
 
-    print_tty "\nData dir is where ubic stores all of its data: locks,\n";
+    print_tty "\nData dir is a directory into which ubic stores all of its data: locks,\n";
     print_tty "status files, tmp files.\n";
-    my $default_data_dir = (
-        defined($local_dir)
-        ? "$local_dir/ubic/data"
-        : $defaults{data_dir}
-    );
+    my $default_data_dir = ($is_root ? '/var/lib/ubic' : "$home/ubic/data");
     $default_data_dir = $opt_data_dir if defined $opt_data_dir;
     my $data_dir = prompt_str("Data dir?", $default_data_dir);
 
-    print_tty "\nLog dir is where ubic.watchdog will write its logs.\n";
+    print_tty "\nLog dir is a directory into which ubic.watchdog will write its logs.\n";
     print_tty "(Your own services are free to write logs wherever they want.)\n";
-    my $default_log_dir = (
-        defined($local_dir)
-        ? "$local_dir/ubic/log"
-        : $defaults{log_dir}
-    );
+    my $default_log_dir = ($is_root ? '/var/log/ubic' : "$home/ubic/log");
     $default_log_dir = $opt_log_dir if defined $opt_log_dir;
     my $log_dir = prompt_str("Log dir?", $default_log_dir);
 
@@ -272,52 +209,10 @@ sub setup {
         print_tty "there are any problems with their statuses.\n";
         print_tty "It is very simple and robust, but since it's important that watchdog never\n";
         print_tty "goes down, we recommended to install the cron job which checks watchdog itself.\n";
-        print_tty "Also, this cron job will bring watchdog and all other services online on host reboots.\n";
         $enable_crontab = prompt_bool("Install watchdog's watchdog as a cron job?", $opt_crontab);
     }
 
-    my $crontab_env_fix = '';
-    my $crontab_wrap_bash;
-    my $ubic_watchdog_full_name = which('ubic-watchdog') or die "ubic-watchdog script not found in your current PATH";
-    {
-        my @path = split /:/, $ENV{PATH};
-        my @perls = grep { -x $_ } map { "$_/perl" } @path;
-        if ($perls[0] =~ /perlbrew/) {
-            print_tty "\nYou're using perlbrew.\n";
-
-            my $HOME = $ENV{ORIGINAL_HOME} || $ENV{HOME}; # ORIGINAL_HOME is set in ubic tests
-            unless ($HOME) {
-                die "HOME env variable not defined";
-            }
-            my $perlbrew_config = File::Spec->catfile($ENV{PERLBREW_ROOT} || "$HOME/perl5/perlbrew", "etc/bashrc");
-            if (not -e $perlbrew_config) {
-                die "Can't find perlbrew config (assumed $perlbrew_config)";
-            }
-            print_tty "I'll source your perlbrew config in ubic crontab entry to start the watchdog in the correct environment.\n";
-            $crontab_env_fix .= "source $perlbrew_config && ";
-            $crontab_wrap_bash = 1;
-        }
-        elsif (@perls > 1) {
-            print_tty "\nYou're using custom perl and it's not from perlbrew.\n";
-            print_tty "I'll add your current PATH to ubic crontab entry.\n";
-
-            # TODO - what if PATH contains " quotes? hopefully nobody is that crazy...
-            $crontab_env_fix .= qq[PATH="$ENV{PATH}" ];
-        }
-
-        if ($ENV{PERL5LIB}) {
-            print_tty "\nYou're using custom PERL5LIB.\n";
-            print_tty "I'll add your current PERL5LIB to ubic crontab entry.\n";
-            print_tty "Feel free to edit your crontab manually after installation if necessary.\n";
-            $crontab_env_fix .= qq[PERL5LIB="$ENV{PERL5LIB}" ];
-        }
-    }
-
-    my $config_file = (
-        defined($local_dir)
-        ?  "$local_dir/.ubic.cfg"
-        : $defaults{config}
-    );
+    my $config_file = ($is_root ? '/etc/ubic/ubic.cfg' : "$home/.ubic.cfg");
 
     {
         print_tty "\nThat's all I need to know.\n";
@@ -329,16 +224,18 @@ sub setup {
 
     print "Installing dirs...\n";
 
-    mkpath($_) for ($service_dir, $data_dir, $log_dir);
+    xsystem('mkdir', '-p', '--', $service_dir);
+    xsystem('mkdir', '-p', '--', $data_dir);
+    xsystem('mkdir', '-p', '--', $log_dir);
 
     for my $subdir (qw[
         status simple-daemon/pid lock ubic-daemon tmp watchdog/lock watchdog/status
     ]) {
-        mkpath("$data_dir/$subdir");
-        chmod(01777, "$data_dir/$subdir") or die "chmod failed: $!";
+        xsystem('mkdir', '-p', '--', "$data_dir/$subdir");
+        xsystem('chmod', '1777', '--', "$data_dir/$subdir") if $enable_1777;
     }
 
-    mkpath("$service_dir/ubic");
+    xsystem('mkdir', '-p', '--', "$service_dir/ubic");
 
     if ($install_services) {
         my $add_service = sub {
@@ -346,7 +243,9 @@ sub setup {
             print "Installing ubic.$name service...\n";
 
             my $file = "$service_dir/ubic/$name";
-            Ubic::AtomicFile::store($content => $file);
+            open my $fh, '>', $file or die "Can't write to '$file': $!";
+            print {$fh} $content or die "Can't write to '$file': $!";
+            close $fh or die "Can't close '$file': $!";
         };
 
         $add_service->(
@@ -374,31 +273,22 @@ sub setup {
 
     if ($enable_crontab) {
         print "Installing cron jobs...\n";
-
-        system("crontab -l >$data_dir/tmp/crontab.stdout 2>$data_dir/tmp/crontab.stderr");
-        my $old_crontab = slurp("$data_dir/tmp/crontab.stdout");
-        my $stderr = slurp("$data_dir/tmp/crontab.stderr");
-        unlink "$data_dir/tmp/crontab.stdout";
-        unlink "$data_dir/tmp/crontab.stderr";
-        if ($stderr and $stderr !~ /no crontab/) {
+        my $old_crontab = qx(crontab -l);
+        if ($?) {
             die "crontab -l failed";
         }
-
-        my @crontab_lines = split /\n/, $old_crontab;
-        @crontab_lines = grep { $_ !~ /\Qubic-watchdog ubic.watchdog\E/ } @crontab_lines;
-
-        open my $fh, '|-', 'crontab -' or die "Can't run 'crontab -': $!";
-        my $printc = sub {
-            print {$fh} @_ or die "Can't write to pipe: $!";
-        };
-
-        my $crontab_command = "$crontab_env_fix$ubic_watchdog_full_name ubic.watchdog";
-        if ($crontab_wrap_bash) {
-            $crontab_command = "bash -c '$crontab_command'";
+        if ($old_crontab =~ /\subic-watchdog\b/) {
+            print "Looks like you already have ubic commands in your crontab.\n";
+        }
+        else {
+            open my $fh, '|-', 'crontab -' or die "Can't run 'crontab -': $!";
+            my $printc = sub {
+                print {$fh} @_ or die "Can't write to pipe: $!";
+            };
+            $printc->($old_crontab."\n");
+            $printc->("* * * * * ubic-watchdog ubic.watchdog    >>/dev/null 2>>/dev/null\n");
+            close $fh or die "Can't close pipe: $!";
         }
-        push @crontab_lines, "* * * * * $crontab_command    >>$log_dir/watchdog.log 2>>$log_dir/watchdog.err.log";
-        $printc->("$_\n") for @crontab_lines;
-        close $fh or die "Can't close pipe: $!";
     }
 
     print "Installing $config_file...\n";
@@ -420,18 +310,15 @@ sub setup {
 1;
 
 __END__
-
 =pod
 
-=encoding UTF-8
-
 =head1 NAME
 
 Ubic::Admin::Setup - this module handles ubic setup: asks user some questions and configures your system
 
 =head1 VERSION
 
-version 1.57_01
+version 1.27
 
 =head1 DESCRPITION
 
@@ -467,10 +354,6 @@ Ask user a yes/no question.
 
 Invoke C<system> command, throwing exception on errors.
 
-=item B<< slurp($file) >>
-
-Read file contents.
-
 =item B<< setup() >>
 
 Perform setup.
@@ -487,9 +370,10 @@ Vyacheslav Matyukhin <mmcleric@yandex-team.ru>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Yandex LLC.
+This software is copyright (c) 2011 by Yandex LLC.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
+
