@@ -1,6 +1,6 @@
 package Ubic::Cmd;
 BEGIN {
-  $Ubic::Cmd::VERSION = '1.26';
+  $Ubic::Cmd::VERSION = '1.27';
 }
 
 use strict;
@@ -214,9 +214,14 @@ sub traverse($$$) {
 sub print_status($$;$$) {
     my $self = _obj(shift);
     my $service = shift;
-    my $cached = shift;
+    my $force_cached = shift;
     my $results = shift || Ubic::Cmd::Results->new;
 
+    my $user = getpwuid($>);
+    unless (defined $user) {
+        die "Can't detect user by uid $>";
+    }
+
     $self->traverse($service, sub {
         my $service = shift;
         my $name = $service->full_name;
@@ -229,8 +234,10 @@ sub print_status($$;$$) {
         }
 
         my $status;
-        if ($cached) {
+        my $cached;
+        if ($force_cached or $user ne Ubic->service($name)->user) {
             $status = Ubic->cached_status($name);
+            $cached = 1;
         }
         else {
             $status = eval { Ubic->status($name) };
@@ -269,9 +276,6 @@ sub run {
     }
 
     my $command = $params->{command};
-    if ($command eq 'status' and $>) {
-        print "Not a root, printing cached statuses\n";
-    }
 
     my $results = Ubic::Cmd::Results->new;
     for my $name (@names) {
@@ -294,15 +298,12 @@ sub _run_impl {
     my $results = $params->{results};
 
     if ($command eq 'status' or $command eq 'cached-status') {
-        my $cached;
-        if ($command eq 'status' and $>) {
-            $cached = 1;
-        }
+        my $force_cached;
         if ($command eq 'cached-status') {
-            $cached = 1;
+            $force_cached = 1;
         }
         try {
-            $self->print_status($name, $cached, $results);
+            $self->print_status($name, $force_cached, $results);
         }
         catch {
             print STDERR $_;
@@ -386,7 +387,7 @@ Ubic::Cmd - ubic methods with pretty printing.
 
 =head1 VERSION
 
-version 1.26
+version 1.27
 
 =head1 SYNOPSIS
 
@@ -447,11 +448,13 @@ WARNING: exits on invocation!
 
 Process each subservice of C<$name_or_service> with C<$callback>, printing correct indentations.
 
-=item B<< print_status($name, $cached_flag) >>
+=item B<< print_status($name, $force_cached) >>
 
-=item B<< print_status($service, $cached_flag) >>
+=item B<< print_status($name, $force_cached, $results) >>
 
-Print status of given service identified by name or by object. If C<$cached_flag> is true, prints status cached in watchdog file.
+Print status of given service identified by name or by object.
+
+If C<$force_cached> is true, prints status cached in watchdog file. Otherwise, check for real status if current user is B<root> or if current user is equal to service user.
 
 =item B<< run($params_hashref) >>
 
