@@ -1,6 +1,6 @@
 package Ubic::Ping::Service;
-{
-  $Ubic::Ping::Service::VERSION = '1.57_01';
+BEGIN {
+  $Ubic::Ping::Service::VERSION = '1.27';
 }
 
 # ABSTRACT: ubic.ping service
@@ -11,7 +11,7 @@ use warnings;
 use Ubic::Service::Common;
 use Ubic::Daemon qw(:all);
 use Ubic::Result qw(result);
-use Ubic::UA;
+use LWP::Simple;
 use POSIX;
 use Time::HiRes qw(sleep);
 
@@ -20,6 +20,7 @@ use Ubic::Settings;
 use Config;
 
 sub new {
+    # ugly; waiting for druxa's Mopheus to save us all...
     my $port = $ENV{UBIC_SERVICE_PING_PORT} || 12345;
     my $pidfile = Ubic::Settings->data_dir."/ubic-ping.pid";
     my $log = $ENV{UBIC_SERVICE_PING_LOG} || '/dev/null';
@@ -46,20 +47,13 @@ sub new {
             unless ($daemon) {
                 return 'not running';
             }
-            my $ua = Ubic::UA->new(timeout => 1);
-            my $response = $ua->get("http://localhost:$port/ping");
-            if ($response->{error}) {
-                return result('broken', $response->{error});
-            }
-            if ($response->{body} =~ /^ok$/ and $response->{code} == 200) {
-                return result('running', "pid ".$daemon->pid);
-            }
-            else {
-                return result('broken', $response->{body});
-            }
+            my $result = get("http://localhost:$port/ping") || '';
+            return ((
+                $result =~ /^ok$/
+            ) ? result('running', "pid ".$daemon->pid) : result('broken'));
         },
         port => $port,
-        timeout_options => { start => { step => 0.1, trials => 8 }},
+        timeout_options => { start => { step => 0.1, trials => 3 }},
     });
 }
 
@@ -67,18 +61,15 @@ sub new {
 1;
 
 __END__
-
 =pod
 
-=encoding UTF-8
-
 =head1 NAME
 
 Ubic::Ping::Service - ubic.ping service
 
 =head1 VERSION
 
-version 1.57_01
+version 1.27
 
 =head1 INTERFACE SUPPORT
 
@@ -100,9 +91,10 @@ Vyacheslav Matyukhin <mmcleric@yandex-team.ru>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Yandex LLC.
+This software is copyright (c) 2011 by Yandex LLC.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
+
