@@ -1,6 +1,6 @@
 package Ubic::PortMap;
 BEGIN {
-  $Ubic::PortMap::VERSION = '1.26';
+  $Ubic::PortMap::VERSION = '1.27';
 }
 
 use strict;
@@ -9,15 +9,15 @@ use warnings;
 # ABSTRACT: update and read mapping of ports to service names.
 
 
+use Try::Tiny;
+use Params::Validate qw(:all);
+
 use Ubic::Logger;
 use Ubic::Persistent;
 use Ubic;
-use Try::Tiny;
-
-use Params::Validate qw(:all);
 
 sub _portmap_file {
-    my $ubic_dir = $ENV{UBIC_DIR} || '/var/lib/ubic';
+    my $ubic_dir = Ubic->get_data_dir;
     my $PORTMAP_FILE = $ubic_dir.'/portmap';
     return $PORTMAP_FILE;
 }
@@ -86,14 +86,14 @@ Ubic::PortMap - update and read mapping of ports to service names.
 
 =head1 VERSION
 
-version 1.26
+version 1.27
 
 =head1 SYNOPSIS
 
     use Ubic::PortMap;
 
     Ubic::PortMap::update();
-    print Ubic::PortMap::port2name(12345); # ubic-ping
+    print Ubic::PortMap::port2name(12345); # ubic.ping
 
 =head1 METHODS
 
