@@ -1,6 +1,6 @@
 package Ubic::Settings;
-{
-  $Ubic::Settings::VERSION = '1.57_01';
+BEGIN {
+  $Ubic::Settings::VERSION = '1.27';
 }
 
 use strict;
@@ -17,17 +17,13 @@ our $settings;
 
 sub _file_settings {
     my $file_settings = {};
-    my @files;
-    if ($ENV{HOME}) {
-        push @files, "$ENV{HOME}/.ubic.cfg";
+    if ($ENV{HOME} and -e "$ENV{HOME}/.ubic.cfg") {
+        $file_settings = Ubic::Settings::ConfigFile->read("$ENV{HOME}/.ubic.cfg");
     }
-    push @files, '/etc/ubic/ubic.cfg';
-    push @files, '/usr/local/etc/ubic/ubic.cfg';
-    for my $file (@files) {
-        next unless -e $file;
-        return Ubic::Settings::ConfigFile->read($file);
+    elsif (-e "/etc/ubic/ubic.cfg") {
+        $file_settings = Ubic::Settings::ConfigFile->read("/etc/ubic/ubic.cfg");
     }
-    return {};
+    return $file_settings;
 }
 
 sub _env_settings {
@@ -99,18 +95,15 @@ sub check_settings {
 1;
 
 __END__
-
 =pod
 
-=encoding UTF-8
-
 =head1 NAME
 
 Ubic::Settings - ubic settings
 
 =head1 VERSION
 
-version 1.57_01
+version 1.27
 
 =head1 SYNOPSIS
 
@@ -140,14 +133,18 @@ Environment variables I<UBIC_SERVICE_DIR>, I<UBIC_DIR> and I<UBIC_DEFAULT_USER>
 
 =item *
 
-Config file at I<~/.ubic.cfg>, I</etc/ubic/ubic.cfg> or I</usr/local/etc/ubic/ubic.cfg>, in this order;
+Config file at I<~/.ubic.cfg>, if it exists;
 
 =item *
 
-If none of these settings are set, it will fail and advice to run C<ubic-admin setup>.
+Config file at I</etc/ubic/ubic.cfg>, if it exists and config file in home directory doesn't exist.
 
 =back
 
+=head1 INTERFACE SUPPORT
+
+This is considered to be a public class. Any changes to its interface will go through a deprecation cycle.
+
 =head1 METHODS
 
 If any of setting methods is called with new value, this value will be applied for current process only.
@@ -188,9 +185,10 @@ Vyacheslav Matyukhin <mmcleric@yandex-team.ru>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Yandex LLC.
+This software is copyright (c) 2011 by Yandex LLC.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
+
