@@ -1,6 +1,6 @@
 package Ubic::Settings::ConfigFile;
-{
-  $Ubic::Settings::ConfigFile::VERSION = '1.57_01';
+BEGIN {
+  $Ubic::Settings::ConfigFile::VERSION = '1.27';
 }
 
 use strict;
@@ -36,7 +36,7 @@ sub write {
 
     my $content = "";
 
-    for my $key (sort keys %$config) {
+    for my $key (keys %$config) {
         my $value = $config->{$key};
         if ($value =~ /\n/) {
             die "Invalid config line  '$key = $value', values can't contain line breaks";
@@ -57,18 +57,15 @@ sub write {
 1;
 
 __END__
-
 =pod
 
-=encoding UTF-8
-
 =head1 NAME
 
 Ubic::Settings::ConfigFile - single ubic config file
 
 =head1 VERSION
 
-version 1.57_01
+version 1.27
 
 =head1 SYNOPSIS
 
@@ -108,9 +105,10 @@ Vyacheslav Matyukhin <mmcleric@yandex-team.ru>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Yandex LLC.
+This software is copyright (c) 2011 by Yandex LLC.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
+
