@@ -1,6 +1,6 @@
 package Ubic::Watchdog;
-{
-  $Ubic::Watchdog::VERSION = '1.57_01';
+BEGIN {
+  $Ubic::Watchdog::VERSION = '1.27';
 }
 
 use strict;
@@ -10,7 +10,6 @@ use warnings;
 
 
 use POSIX;
-use IO::Handle;
 use Params::Validate qw(:all);
 use Try::Tiny;
 use List::MoreUtils qw(any);
@@ -107,8 +106,6 @@ sub check($) {
 
     try {
         alarm($service->check_timeout);
-
-        # TODO - do additional fork, so that if service code overrides SIG{ALRM} or resets alarm(), watchdog still will finish in time
         $SIG{ALRM} = sub {
             ERROR("$name check_timeout exceeded");
             STDOUT->flush;
@@ -117,13 +114,10 @@ sub check($) {
             ERROR "kill sent, still alive"; # should never happen, we called setsid earlier
         };
 
-        # permanently use service credentials
-        # this line optimizes the number of fork calls - future status/restart calls would perform forked_call() otherwise
-        Ubic::Credentials->new( service => $service )->set;
-
-        # so we don't need access guard for this lock
-        my $watchdog_lock = Ubic::SingletonLock->new(Ubic->get_data_dir()."/watchdog/lock/".$name, { blocking => 0 });
-
+        my $watchdog_lock = do {
+            my $guard = Ubic->access_guard($name);
+            Ubic::SingletonLock->new(Ubic->get_data_dir()."/watchdog/lock/".$name, { blocking => 0 });
+        };
         unless ($watchdog_lock) {
             if ($self->{verbose}) {
                 INFO "$name is locked by another watchdog process";
@@ -137,33 +131,22 @@ sub check($) {
             return;
         }
 
-        my $cached_status = Ubic->cached_status($name);
         my $status = Ubic->status($name);
         unless ($status->status eq 'running') {
-            # following code can throw an exception, so we want to cache invalid status immediately
-            Ubic->set_cached_status($name, $status);
-
-            if ($cached_status eq "autostarting") {
-                INFO("$name is autostarting");
-            }
-            else {
-                ERROR("$name status is '$status', restarting");
-            }
-
-            Ubic->restart($name);
-
-            # This is a precaution against services with wrong start/status logic.
-            $status = Ubic->status($name);
-            if ($status->status ne 'running') {
-                INFO("$name started, but status is still '$status'");
-            }
+            Ubic->set_cached_status($name, $status->status); # following start can throw exception
+            ERROR("$name is broken, restarting");
+            Ubic->start($name);
         }
-
+        $status = Ubic->status($name);
         alarm(0);
+
+        if ($status->status ne 'running') {
+            INFO("$name started, but status is still '$status'");
+        }
         Ubic->set_cached_status($name, $status); # if service's start implementation is invalid, ubic-watchdog will restart it every minute, so be careful
     }
     catch {
-        ERROR("Failed to revive $name: $_");
+        ERROR("Failed to check $name: $_");
     };
 
     INFO("$name checked") if $self->{verbose};
@@ -173,18 +156,15 @@ sub check($) {
 1;
 
 __END__
-
 =pod
 
-=encoding UTF-8
-
 =head1 NAME
 
 Ubic::Watchdog - watchdog code
 
 =head1 VERSION
 
-version 1.57_01
+version 1.27
 
 =head1 SYNOPSIS
 
@@ -261,9 +241,10 @@ Vyacheslav Matyukhin <mmcleric@yandex-team.ru>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Yandex LLC.
+This software is copyright (c) 2011 by Yandex LLC.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
+
